@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.88 2005/01/18 20:56:55 vnoel Exp $ */
+/* $Id: gdict-applet.c,v 1.93 2005/09/23 14:34:39 vnoel Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -41,8 +41,11 @@ entry_activate_cb (GtkEntry *entry, gpointer data)
   gtk_window_move (GTK_WINDOW (gdict), gdict->x, gdict->y);
   gtk_window_present (GTK_WINDOW (gdict));
     
-  if (text==NULL || *text == 0)
+  if (text == NULL || *text == 0) {
+    if (text != NULL)
+      g_free (text);
     return;
+  }
 
   gtk_editable_delete_text (GTK_EDITABLE (entry), 0, -1);
   if (gdict->search_type == SEARCH_TYPE_REGULAR)
@@ -99,7 +102,7 @@ lookup_button_drag_cb (GtkWidget *widget, GdkDragContext *context, gint x, gint
   GDictApplet *applet = data;
   gchar *text;
   
-  text = gtk_selection_data_get_text (sd);
+  text = (gchar *) gtk_selection_data_get_text (sd);
   
   if (text && *text) {
     gtk_entry_set_text (GTK_ENTRY (applet->entry_widget), text);
@@ -181,7 +184,7 @@ change_background (PanelApplet *applet, PanelAppletBackgroundType type,
   gtk_widget_set_style (GTK_WIDGET (applet), NULL);
   rc_style = gtk_rc_style_new ();
   gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-  g_object_unref (rc_style);
+  gtk_rc_style_unref (rc_style);
 
   switch (type) {
   case PANEL_NO_BACKGROUND:
@@ -196,6 +199,7 @@ change_background (PanelApplet *applet, PanelAppletBackgroundType type,
       g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
     style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
     gtk_widget_set_style (GTK_WIDGET (applet), style);
+    g_object_unref (style);
     break;
   }
 }
@@ -235,6 +239,8 @@ destroy_applet (GtkWidget *widget, gpointer data)
   gtk_widget_destroy (applet->entry_widget);
   gtk_widget_destroy (applet->box);
   gtk_widget_destroy (applet->applet_widget);
+  gtk_widget_destroy (GTK_WIDGET (applet->gdict));
+  g_free (applet);
 }
 
 static void
@@ -273,27 +279,7 @@ about_cb (BonoboUIComponent *uic,
           gpointer           user_data,
           const gchar       *verbname)
 {
-  GDictApplet *applet = user_data;
-
-  if (applet->about_dialog) {
-    gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
-               gtk_widget_get_screen (applet->applet_widget));
-
-    gtk_window_present (GTK_WINDOW (applet->about_dialog));
-    return;
-  }
-
-  applet->about_dialog = gdict_about_new ();
-
-  gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
-             gtk_widget_get_screen (applet->applet_widget));
-
-  g_signal_connect (G_OBJECT (applet->about_dialog), "response",
-        G_CALLBACK (gtk_widget_destroy), NULL);
-  g_signal_connect (G_OBJECT (applet->about_dialog), "destroy",
-        G_CALLBACK (gtk_widget_destroyed), &applet->about_dialog);
-
-  gtk_widget_show (applet->about_dialog);
+	gdict_about (NULL);
 }
 
 static void
@@ -362,6 +348,7 @@ gdict_applet_new (PanelApplet *parent_applet)
   applet->panel_size = panel_applet_get_size (PANEL_APPLET (applet->applet_widget));
   applet->orient = panel_applet_get_orient (PANEL_APPLET (applet->applet_widget));
   
+  g_set_application_name (_("Dictionary"));
   gtk_window_set_default_icon_name ("gdict");
   
   panel_applet_set_flags (parent_applet, PANEL_APPLET_EXPAND_MINOR);
@@ -378,6 +365,7 @@ gdict_applet_new (PanelApplet *parent_applet)
 
   gdict->applet = applet;
   applet->gdict = gdict;
+  gdict_pref_load (gdict, gdict->pref);
 
   panel_applet_setup_menu_from_file (PANEL_APPLET (applet->applet_widget),
                                      NULL, "GNOME_GDictApplet.xml",
@@ -394,9 +382,6 @@ gdict_applet_new (PanelApplet *parent_applet)
                                   NULL);
   }
 
-  /* server will be contacted when an action is performed */
-  gdict->context = NULL;
-  
   component = panel_applet_get_popup_component (PANEL_APPLET(applet->applet_widget));
   
   g_signal_connect (G_OBJECT (applet->applet_widget), "size_allocate",
