@@ -19,6 +19,8 @@
     ---------------------------------------------------------------------- */
 
 #include <config.h>
+#include <stdlib.h>
+#include <string.h>
 #include <gconf/gconf-client.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomeui/gnome-ui-init.h>
@@ -200,7 +202,8 @@ logview_save_prefs (LogviewWindow *logview)
       log = list->data;
       user_prefs->logs = g_slist_append (user_prefs->logs, log->name);
 	}
-  user_prefs->logfile = logview->curlog->name;
+  if (logview->curlog)
+    user_prefs->logfile = logview->curlog->name;
 	user_prefs->fontsize = logview->fontsize;
 	if (restoration_complete)
 		prefs_save (client, user_prefs);
@@ -216,7 +219,7 @@ destroy (GObject *object, gpointer data)
 {
    LogviewWindow *window = data;
    logview_windows = g_slist_remove (logview_windows, window);
-   if (window->curlog->monitored)
+   if (window->curlog && window->curlog->monitored)
 	   monitor_stop (window);
    if (logview_windows == NULL) {
 	   if (window->curlog && !(window->curlog->display_name))
@@ -263,6 +266,7 @@ static gint
 die (GnomeClient *gnome_client, gpointer client_data)
 {
     gtk_main_quit ();
+    return 0;
 }
 
 void
@@ -314,6 +318,7 @@ logview_add_logs_from_names (LogviewWindow *logview, GSList *lognames)
 	}
 }
 
+void
 logview_remove_log (LogviewWindow *logview, Log *log)
 {
 	CloseLog (log);
@@ -821,7 +826,7 @@ FileSelectResponse (GtkWidget * chooser, gint response, gpointer data)
    if (f != NULL) {
 	   /* Check if the log is not already opened */
 	   GList *list;
-		 Log *log;
+		 Log *log, *tl;
 	   for (list = logview->logs; list != NULL; list = g_list_next (list)) {
 		   log = list->data;
 		   if (g_ascii_strncasecmp (log->name, f, 255) == 0) {
@@ -830,7 +835,6 @@ FileSelectResponse (GtkWidget * chooser, gint response, gpointer data)
 		   }
 	   }
 
-	   Log *tl;
 	   if ((tl = OpenLogFile (f, TRUE)) != NULL)
 	     logview_add_log (logview, tl);
    }
@@ -1166,22 +1170,23 @@ logview_menus_set_state (LogviewWindow *window)
 				logview_menu_item_set_state (window, "/LogviewMenu/FileMenu/MonitorLogs", FALSE);
 			else
 				logview_menu_item_set_state (window, "/LogviewMenu/FileMenu/MonitorLogs", TRUE);
-
-            if (window->curlog->has_date)
-                logview_menu_item_set_state (window, "/LogviewMenu/ViewMenu/ShowCalendar", (window->curlog != NULL));
-            else
-                logview_menu_item_set_state (window, "/LogviewMenu/ViewMenu/ShowCalendar", FALSE);
-
-		} else
+      
+      if (window->curlog->has_date)
+        logview_menu_item_set_state (window, "/LogviewMenu/ViewMenu/ShowCalendar", TRUE);
+      else
+        logview_menu_item_set_state (window, "/LogviewMenu/ViewMenu/ShowCalendar", FALSE);
+      
+		} else {
 			logview_menu_item_set_state (window, "/LogviewMenu/FileMenu/MonitorLogs", FALSE);
-		
+      logview_menu_item_set_state (window, "/LogviewMenu/ViewMenu/ShowCalendar", FALSE);
+		}
+
 		logview_menu_item_set_state (window, "/LogviewMenu/FileMenu/Properties", (window->curlog != NULL));
 		logview_menu_item_set_state (window, "/LogviewMenu/FileMenu/CloseLog", (window->curlog != NULL));
 		logview_menu_item_set_state (window, "/LogviewMenu/ViewMenu/CollapseAll", (window->curlog != NULL));
 		logview_menu_item_set_state (window, "/LogviewMenu/EditMenu/Search", (window->curlog != NULL));
 		logview_menu_item_set_state (window, "/LogviewMenu/EditMenu/Copy", (window->curlog != NULL));
 		logview_menu_item_set_state (window, "/LogviewMenu/EditMenu/SelectAll", (window->curlog != NULL));
-        logview_menu_item_set_state (window, "/LogviewMenu/ViewMenu/ShowCalendar", FALSE);
 	}
 }
 
